==> minitube-0.9.tar.gz: minitube/locale/pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Não há vida fora do navegador!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versão %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation>Este é um lançamento &quot;Prévio da Tecnologia&quot;, não esperamos que ela seja perfeita.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Relate as falhas e envie suas ideias para %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 é um Software livre, mas o seu desenvolvimento tem um tempo precioso.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Por favor, &lt;a href=&apos;%1&apos;&gt;doções via PayPal&lt;/a&gt; para apoiar o desenvolvimento contínuo de %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ícone desenhado por %1.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Traduzido por %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Lançado sob a &lt;a href=&apos;%1&apos;&gt;Licença Pública Geral GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>O que você sempre quis saber sobre %1 e nunca se atreveu a perguntar</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Modo compacto contribuído por %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>Suporte a HTTP proxy contribuído por %1.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">Vesão da janela construída por %1</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Localizando...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Mostrar %1 a mais</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Não há vídeos</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Não há mais vídeos</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Voltar</translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation type="obsolete">Alt+Left</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Ir para a visualização anterior</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Parar</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Parar a reprodução e voltar à visualização da pesquisa</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation type="obsolete">Esc</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>Pu&amp;lar</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Pular para o próximo vídeo</translation>
    </message>
    <message>
        <source>Ctrl+Right</source>
        <translation type="obsolete">Ctrl+Right</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausar</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pausar a reprodução</translation>
    </message>
    <message>
        <source>Space</source>
        <translation type="obsolete">Barra de espaço</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Tela Cheia</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Ir para a tela cheia</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation type="obsolete">Alt+Enter</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation>&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation>Abrir a página de vídeo do YouTube</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation type="obsolete">Ctrl+Y</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Remover os vídeos selecionados da playlist</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mover para &amp;cima</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Mover para cima os vídeos selecionados na playlist</translation>
    </message>
    <message>
        <source>Ctrl+Up</source>
        <translation type="obsolete">Ctrl+Up</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mover para &amp;baixo</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Mover para baixo os vídeos selecionados na playlist</translation>
    </message>
    <message>
        <source>Ctrl+Down</source>
        <translation type="obsolete">Ctrl+Down</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Tchau</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Website</translation>
    </message>
    <message>
        <source>Minitube on the Web</source>
        <translation type="obsolete">Minitube na Web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 na Web</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation>&amp;Doações via PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Por favor, apoiem o desenvolvimento contínuo de %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Sobre</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informações sobre %1</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation type="obsolete">&amp;Pesquisar</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation type="unfinished">&amp;Aplicação</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Playlist</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Vídeo</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Abrindo %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Reproduzir</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Continuar reprodução</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Sair de &amp;Tela Cheia</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>Modo &amp;compacto</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Escolher a playlist e a barra de tarefas</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Erro fatal: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Erro: %1</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volume a %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Volume está mudo</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Volume não está mudo</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Volume nudo</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Pressione %1 para aumentar o volume, %2 para diminui-lo</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tempo restante: %1</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation>Vídeo de Alta Definição está habilitado</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation>Vídeo de Alta Definição não está habilitado</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation>O vídeo atual está em Alta Definição</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation>O vídeo atual nõ está em Alta Definição</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation type="unfinished">Palavras-chave &amp;limpas recentemente</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Mais relevantes</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Mais recentes</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Mais vistos</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Você está assistindo &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Erro na rede: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 exibições</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bem-vindo ao &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Digite uma palavra-chave para começar a assistir os vídeos.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Assistir</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Palavra-chave recente</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Um nova versão de %1 está disponível. Por favor, &lt;a href=&apos;%2&apos;&gt;atualize para a versão %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Sinta-se confortável</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation>Preferências</translation>
    </message>
    <message>
        <source>&amp;Video options</source>
        <translation type="obsolete">Opções de &amp;vídeo</translation>
    </message>
    <message>
        <source>Use high quality video when available</source>
        <translation type="obsolete">Utilizar vídeo de alta qualidade quando estiver disponível</translation>
    </message>
    <message>
        <source>&amp;Saved recent keywords</source>
        <translation type="obsolete">Palavras-chave &amp;salvas recentemente</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation type="obsolete">Palavras-chave &amp;limpas recentemente</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">&amp;Fechar</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Erro na rede: %1 para %2</translation>
    </message>
</context>
</TS>

==> minitube-1.0.tar.gz: minitube/locale/pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Não há vida fora do navegador!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versão %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation type="obsolete">Este é um lançamento &quot;Prévio da Tecnologia&quot;, não esperamos que ela seja perfeita.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Relate as falhas e envie suas ideias para %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 é um Software livre, mas o seu desenvolvimento tem um tempo precioso.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation type="obsolete">Por favor, &lt;a href=&apos;%1&apos;&gt;doções via PayPal&lt;/a&gt; para apoiar o desenvolvimento contínuo de %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ícone desenhado por %1.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Traduzido por %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Lançado sob a &lt;a href=&apos;%1&apos;&gt;Licença Pública Geral GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>O que você sempre quis saber sobre %1 e nunca se atreveu a perguntar</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Modo compacto contribuído por %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>Suporte a HTTP proxy contribuído por %1.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">Vesão da janela construída por %1</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Por favor &lt;a href=&apos;%1&apos;&gt;doe&lt;/a&gt; para apoiar o desenvolvimento contínuo de %2.</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Pesquisando...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Mostrar %1 a mais</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Não há vídeos</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Não há mais vídeos</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation type="obsolete">&amp;Voltar</translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation type="obsolete">Alt+Left</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation type="obsolete">Ir para a visualização anterior</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Parar</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Parar a reprodução e voltar à visualização da pesquisa</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation type="obsolete">Esc</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>Pu&amp;lar</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Pular para o próximo vídeo</translation>
    </message>
    <message>
        <source>Ctrl+Right</source>
        <translation type="obsolete">Ctrl+Right</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausar</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pausar a reprodução</translation>
    </message>
    <message>
        <source>Space</source>
        <translation type="obsolete">Barra de espaço</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Tela Cheia</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Ir para a tela cheia</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation type="obsolete">Alt+Enter</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation type="obsolete">&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation type="obsolete">Abrir a página de vídeo do YouTube</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation type="obsolete">Ctrl+Y</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Remover os vídeos selecionados da playlist</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mover para &amp;cima</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Mover para cima os vídeos selecionados na playlist</translation>
    </message>
    <message>
        <source>Ctrl+Up</source>
        <translation type="obsolete">Ctrl+Up</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mover para &amp;baixo</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Mover para baixo os vídeos selecionados na playlist</translation>
    </message>
    <message>
        <source>Ctrl+Down</source>
        <translation type="obsolete">Ctrl+Down</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Tchau</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Si&amp;te</translation>
    </message>
    <message>
        <source>Minitube on the Web</source>
        <translation type="obsolete">Minitube na Web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 na Web</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation type="obsolete">&amp;Doações via PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Por favor, apoie o desenvolvimento contínuo de %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Sobre</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informações sobre %1</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation type="obsolete">&amp;Pesquisar</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplicação</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Playlist</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Vídeo</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Abrindo %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Reproduzir</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Continuar reprodução</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Sair de &amp;Tela Cheia</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>Modo &amp;compacto</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Ocultar a playlist e a barra de ferramentas</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Erro fatal: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Erro: %1</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volume a %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Volume está mudo</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Volume não está mudo</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Volume mudo</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Pressione %1 para aumentar o volume, %2 para diminui-lo</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tempo restante: %1</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation type="obsolete">Vídeo de Alta Definição está habilitado</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation type="obsolete">Vídeo de Alta Definição não está habilitado</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation type="obsolete">O vídeo atual está em Alta Definição</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation type="obsolete">O vídeo atual nõ está em Alta Definição</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>&amp;Apagar palavras-chave recentes</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Apagar o histórico de pesquisa. Não pode ser desfeito.</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Sua privacidade está agora segura</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube page</source>
        <translation>Abrir a página do &amp;YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Ir à página de vídeo do YouTube e pausar a reprodução</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;link</source>
        <translation>Copiar o &amp;link do YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Copiar o link do vídeo atual do YouTube para a área de transferência</translation>
    </message>
    <message>
        <source>Copy the video stream &amp;URL</source>
        <translation>Copiar a &amp;URL do stream do vídeo</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Copiar a URL do stream do vídeo atual para a área de transferência</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Faça uma &amp;doação</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Máxima definição de vídeo definida para %1</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Mais relevantes</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Mais recentes</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Mais vistos</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Você está assistindo &quot;%1&quot;</translation>
    </message>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Agora você pode colar o link do YouTube em outro programa</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Agora você pode colar a URL do stream de vídeo em outro programa</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>O link só será válido por um tempo limitado.</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Erro na rede: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 exibições</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bem-vindo ao &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Digite uma palavra-chave para começar a assistir os vídeos.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Assistir</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Palavra-chave recente</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Um nova versão de %1 está disponível. Por favor, &lt;a href=&apos;%2&apos;&gt;atualize para a versão %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Sinta-se confortável</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Preferências</translation>
    </message>
    <message>
        <source>&amp;Video options</source>
        <translation type="obsolete">Opções de &amp;vídeo</translation>
    </message>
    <message>
        <source>Use high quality video when available</source>
        <translation type="obsolete">Utilizar vídeo de alta qualidade quando estiver disponível</translation>
    </message>
    <message>
        <source>&amp;Saved recent keywords</source>
        <translation type="obsolete">Palavras-chave &amp;salvas recentemente</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation type="obsolete">Palavras-chave &amp;limpas recentemente</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">&amp;Fechar</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Erro na rede: %1 para %2</translation>
    </message>
</context>
</TS>
